@@ -27,10 +27,10 @@ import (
 	minterv1 "github.com/openshift/cloud-credential-operator/pkg/apis/cloudcredential/v1"
 	ccaws "github.com/openshift/cloud-credential-operator/pkg/aws"
 	minteraws "github.com/openshift/cloud-credential-operator/pkg/aws"
-	actuatoriface "github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/actuator"
-	awsannotator "github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/aws"
-	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/constants"
-	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
+	actuatoriface "github.com/openshift/cloud-credential-operator/pkg/operator/credentialsrequest/actuator"
+	awsannotator "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/aws"
+	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/constants"
+	"github.com/openshift/cloud-credential-operator/pkg/operator/utils"
 
 	configv1 "github.com/openshift/api/config/v1"
 
@@ -883,9 +883,10 @@ func (a *AWSActuator) getDesiredUserPolicy(entries []minterv1.StatementEntry, us
 	}
 	for _, se := range entries {
 		policyDoc.Statement = append(policyDoc.Statement, StatementEntry{
-			Effect:   se.Effect,
-			Action:   se.Action,
-			Resource: se.Resource,
+			Effect:    se.Effect,
+			Action:    se.Action,
+			Resource:  se.Resource,
+			Condition: se.PolicyCondition,
 		})
 	}
 
@@ -1136,9 +1137,10 @@ type PolicyDocument struct {
 // StatementEntry is a simple type used to serialize to AWS' PolicyDocument format. We cannot
 // re-use minterv1.StatementEntry due to different conventions for the serialization keys. (caps)
 type StatementEntry struct {
-	Effect   string
-	Action   []string
-	Resource string
+	Effect    string
+	Action    []string
+	Resource  string
+	Condition minterv1.IAMPolicyCondition `json:",omitempty"`
 }
 
 func (a *AWSActuator) loadClusterUUID(logger log.FieldLogger) (configv1.ClusterID, error) {
